@@ -1,6 +1,6 @@
 /* FIGARO'S PASSWORD MANAGER 2 (FPM2)
  * Copyright (C) 2000 John Conneely
- * Copyright (C) 2008-2018 Aleš Koval
+ * Copyright (C) 2008-2025 Aleš Koval
  *
  * FPM is open source / free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1046,7 +1046,7 @@ void
 on_lock1_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-    fpm_lock();
+    fpm_lock(NULL);
 }
 
 
@@ -1536,7 +1536,6 @@ on_view_menu_activate                  (GtkMenuItem     *menuitem,
 
 }
 
-
 void
 on_dblclick_action_combo_changed       (GtkComboBox     *combobox,
                                         gpointer         user_data)
@@ -1544,7 +1543,6 @@ on_dblclick_action_combo_changed       (GtkComboBox     *combobox,
     ini->dblclick_action = gtk_combo_box_get_active(combobox);
 }
 
-
 void
 on_startup_search_toggled              (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
