@@ -1,6 +1,6 @@
 /* FIGARO'S PASSWORD MANAGER 2 (FPM2)
  * Copyright (C) 2000 John Conneely
- * Copyright (C) 2008-2017 Aleš Koval
+ * Copyright (C) 2008-2025 Aleš Koval
  *
  * FPM is open source / free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,9 +49,6 @@ on_button_new_clicked                  (GtkButton       *button,
 void
 on_clist_main_select_row               (GtkTreeView *treeview,
 					gpointer data);
-void
-on_clist_main_select_row2               (GtkTreeSelection *selection,
-					gpointer data);
 
 void
 on_button_edit_clicked                 (GtkButton       *button,
@@ -150,11 +147,6 @@ on_entry_password_activate             (GtkEditable     *editable,
 void
 on_button_cpw_ok_clicked               (GtkButton       *button,
                                         gpointer         user_data);
-/*
-void
-on_button_cpw_cancel_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-*/
 
 void
 on_copy_pass_activate                  (GtkMenuItem     *menuitem,
@@ -212,11 +204,6 @@ void
 on_entry_changed                       (GtkEditable     *editable,
                                         gpointer         user_data);
 
-gboolean
-on_dialog_edit_passitem_delete_event   (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
 void
 on_open1_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -275,123 +262,6 @@ void
 on_find_entry_activate                 (GtkEntry        *entry,
                                         gpointer         user_data);
 
-
-void
-on_app_safe_destroy                    (GtkWidget       *object,
-                                        gpointer         user_data);
-
-gboolean
-on_app_safe_delete_event               (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-void
-on_open1_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_save1_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_save_as1_activate                   (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_import_passwords1_activate          (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_export1_activate                    (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_exit1_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_copy_pass_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_copy_user_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_add_item1_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_edit_item1_activate                 (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_find_activate                       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_item_delete_activate                (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_preferences1_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_item_password_activate              (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_preferences2_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_current_password_file1_activate     (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_about1_activate                     (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_optionmenu_category_changed         (GtkComboBox     *combobox,
-                                        gpointer         user_data);
-
-gboolean
-on_clist_main_button_press_event       (GtkWidget       *widget,
-                                        GdkEventButton  *event,
-                                        gpointer         user_data);
-
-gboolean
-on_clist_main_button_release_event     (GtkWidget       *widget,
-                                        GdkEventButton  *event,
-                                        gpointer         user_data);
-
-void
-on_clist_main_select_row               (GtkTreeView     *treeview,
-                                        gpointer         user_data);
-
-void
-on_find_close_clicked                  (GtkToolButton   *toolbutton,
-                                        gpointer         user_data);
-
-gboolean
-on_find_entry_key_press_event          (GtkWidget       *widget,
-                                        GdkEventKey     *event,
-                                        gpointer         user_data);
-
-void
-on_find_entry_changed                  (GtkEditable     *editable,
-                                        gpointer         user_data);
-
-void
-on_find_entry_activate                 (GtkEntry        *entry,
-                                        gpointer         user_data);
-
-void
-on_find_match_case_toggled             (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 tray_icon_on_click			(GtkStatusIcon *status_icon, 
 					 gpointer user_data);
@@ -486,10 +356,6 @@ void
 on_select_key_file_clicked             (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_dialog_edit_passitem_destroy        (GtkWidget       *object,
-                                        gpointer         user_data);
-
 void
 on_copy_target_combo_changed        (GtkComboBox     *combobox,
                                         gpointer         user_data);
