@@ -1,6 +1,6 @@
 /* FIGARO'S PASSWORD MANAGER 2 (FPM2)
  * Copyright (C) 2000 John Conneely
- * Copyright (C) 2008-2020 Aleš Koval
+ * Copyright (C) 2008-2025 Aleš Koval
  *
  * FPM is open source / free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -145,7 +145,7 @@ void fpm_init (char* opt_file_name, int tray_on_startup) {
 	    ini->tr_always_visible = TRUE;
 	    state->minimized = TRUE;
 	    fpm_tray_icon();
-	    fpm_lock();
+	    fpm_lock(NULL);
 	} else {
 	    gtk_widget_show(gui->pass_window);
 	}
@@ -169,7 +169,7 @@ void fpm_init (char* opt_file_name, int tray_on_startup) {
     }
 }
 
-void fpm_check_password () {
+void fpm_check_password (void) {
     GtkEntry *entry;
     GtkLabel *label;
     GtkComboBoxText *combo_box;
@@ -287,21 +287,21 @@ void fpm_check_password () {
 
 }
 
-void lock_fpm_file(gchar* glb_filename)
+void lock_fpm_file(gchar *filename)
 {
 	gchar *dia_str;
 
-	if ((lock_fd = open (glb_filename, O_RDWR)) < 0) {
+	if ((lock_fd = open (filename, O_RDWR)) < 0) {
 	    dia_str = g_strdup_printf(_("Could not open %s"), 
 			glb_filename);
 	    fpm_message (GTK_WINDOW(gui->main_window), dia_str, GTK_MESSAGE_ERROR);
-	    perror(glb_filename);
+	    perror(filename);
 	    exit(1);
 	}
 
 	if (flock (lock_fd, LOCK_EX | LOCK_NB)) {
 	    dia_str = g_strdup_printf (_("Could not lock %s\nFile already locked."), 
-			glb_filename);
+			filename);
 	    fpm_message(GTK_WINDOW(gui->main_window), dia_str, GTK_MESSAGE_ERROR);
 	    printf ("%s\n", dia_str);
 	    exit (1);
@@ -572,7 +572,7 @@ fpm_set_entry(GtkWidget* win, gchar* entry_name, char* text)
 }
 
 
-void fpm_unlock() {
+void fpm_unlock(void) {
     GtkLabel *label;
 
     label = GTK_LABEL(lookup_widget(gui->pass_window, "label_password_message"));
@@ -835,7 +835,7 @@ cont:
     fpm_message(GTK_WINDOW(gui->main_window), _("This password's launcher is undefined.\nPlease define it in the edit password item screen."), GTK_MESSAGE_WARNING);
 }
 
-void fpm_set_password()
+void fpm_set_password(void)
 {
   GtkEntry *entry;
   GtkComboBoxText *combo_box;
@@ -915,7 +915,7 @@ void fpm_set_password()
   g_free(pw2);
 }
 
-void fpm_clear_list()
+void fpm_clear_list(void)
 {
   GList *list;
   GtkTreeModel *list_store;
@@ -933,7 +933,7 @@ void fpm_clear_list()
   gtk_list_store_clear(GTK_LIST_STORE(list_store));
 }
 
-void fpm_init_launchers()
+void fpm_init_launchers(void)
 {
   GList * list;
   fpm_launcher* launcher;
@@ -966,7 +966,7 @@ void fpm_init_launchers()
   fpm_create_launcher_string_list();
 }
 
-void fpm_create_launcher_string_list()
+void fpm_create_launcher_string_list(void)
 {
   GList * list;
   fpm_launcher* launcher;
@@ -1076,7 +1076,7 @@ void fpm_message (GtkWindow *parent_window, gchar *message, GtkMessageType messa
     gtk_widget_destroy (dialog);
 }
 
-void fpm_ini_load()
+void fpm_ini_load(void)
 {
     GKeyFile *keyfile;
     GError *error = NULL;
@@ -1179,8 +1179,8 @@ void fpm_ini_load()
 	    columns_order = g_list_append (columns_order, GINT_TO_POINTER (FPM_URL));
 	    columns_order = g_list_append (columns_order, GINT_TO_POINTER (FPM_USER));
 	} else {
-	    for (gsize i = 0; i < count; i++)
-		columns_order = g_list_append (columns_order, GINT_TO_POINTER (columns[i]));
+	    for (gsize j = 0; j < count; j++)
+		columns_order = g_list_append (columns_order, GINT_TO_POINTER (columns[j]));
 	    g_free(columns);
 	}
 
@@ -1274,7 +1274,7 @@ void fpm_ini_load()
     g_key_file_free (keyfile);
 }
 
-void fpm_ini_save()
+void fpm_ini_save(void)
 {
     GKeyFile *keyfile;
     gint x, y, width, height;
@@ -1449,14 +1449,14 @@ void fpm_statusbar_push(gchar *message)
     gtk_statusbar_push(statusbar, 1, message);
 }
 
-gboolean fpm_auto_hide() {
+gboolean fpm_auto_hide(gpointer user_data) {
 
     fpm_tr_toggle_main_window(TRUE);
 
     return FALSE;
 }
 
-void fpm_tray_icon() {
+void fpm_tray_icon(void) {
 
     if (gui->tray_icon == NULL) {
 //	gui->tray_icon = gtk_status_icon_new();
@@ -1551,14 +1551,14 @@ void fpm_tr_toggle_main_window (gboolean force_hide) {
 }
 
 
-void fpm_tr_cleanup() {
+void fpm_tr_cleanup(void) {
     if (gui->tray_icon) {
 	gtk_status_icon_set_visible (gui->tray_icon, FALSE);
 	gui->tray_icon = (g_object_unref (gui->tray_icon), NULL);
     }
 }
 
-gboolean fpm_lock() {
+gboolean fpm_lock(gpointer user_data) {
     if (!state->minimized)
 	fpm_tr_toggle_main_window(TRUE);
 
@@ -1581,7 +1581,7 @@ gboolean fpm_lock() {
 
 /* This function is called when focus out from main window and we
    need know if focus get another FPM2 window (TRUE) or no (FALSE). */
-gboolean fpm_window_check() {
+gboolean fpm_window_check(void) {
     GList* list;
     list = gtk_window_list_toplevels();
     while (list) {
@@ -1592,7 +1592,7 @@ gboolean fpm_window_check() {
     return FALSE;
 }
 
-void fpm_toolbar_style() {
+void fpm_toolbar_style(void) {
 
     GtkWidget *menuitem;
     GtkToolbar *toolbar;
@@ -1659,7 +1659,7 @@ void fpm_copy_target_combo(GtkComboBoxText *combo_box, gint selection) {
     gtk_combo_box_set_active (GTK_COMBO_BOX(combo_box), selection);
 }
 
-gboolean fpm_valid_edit_data() {
+gboolean fpm_valid_edit_data(void) {
   if (glb_edit_data == NULL) {
     fpm_message(GTK_WINDOW(gui->main_window), _("\nPlease select a row."), GTK_MESSAGE_INFO);
     return(FALSE);
