@@ -1,6 +1,6 @@
 /* FIGARO'S PASSWORD MANAGER 2 (FPM2)
  * Copyright (C) 2000 John Conneely
- * Copyright (C) 2009-2020 Aleš Koval
+ * Copyright (C) 2009-2025 Aleš Koval
  *
  * FPM is open source / free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ static int decrypt_vault (xmlNodePtr node, gchar *adata, byte *tag_old) {
     return (VAULT_DECRYPT_OK);
 }
 
-static void passfile_update_key()
+static void passfile_update_key(void)
 /* This routine goes through the entire password list and will decrypt the
  * passwords with an old key and encrypt it again with a new key.  This is
  * needed in two situations: First, if the user changes a password.  Secondly,
@@ -237,7 +237,7 @@ void fpm_file_save (gchar *file_name, gboolean convert) {
 
     } else {
 
-        gchar *salt = g_base64_encode (crypto->new->salt, FPM_SALT_SIZE);
+        salt = g_base64_encode (crypto->new->salt, FPM_SALT_SIZE);
         xmlSetProp (item, (xmlChar *)"salt", (xmlChar *)salt);
         xmlSetProp (item, (xmlChar *)"iv", (xmlChar *)iv);
         xmlSetProp (item, (xmlChar *)"kdf", (xmlChar *)"PBKDF2");
